MediaKind

Enum MediaKind 

pub enum MediaKind {
    Text,
    File,
    Uri,
    Data,
    Any,
}
A type of media that registered into clipboard or DND system. Text, File, Uri is designed for simple implementation. For programs that wants to send custom MIME, use Data. Cannot support multiple kind of data at the moment.

Variants



Text

A regular text



File

A file path (can be multiple, \n separated)



Uri

A URI path (HTTP or internal identifier)



Data

A data URI



Any

Do not use

Implementations

Source

impl MediaKind

pub const fn from_i64(val: i64) -> Self

pub const fn to_i64(&self) -> i64

pub fn to_mime(&self, data: &str) -> String