pub enum MediaKind {
Text,
File,
Uri,
Data,
Any,
}Expand description
A type of media that registered into clipboard or DND system. Text, File, Uri is designed for simple implementation. For programs that wants to send custom MIME, use Data. Cannot support multiple kind of data at the moment.
Variants
Text
A regular text
File
A file path (can be multiple, \n separated)
Uri
A URI path (HTTP or internal identifier)
Data
A data URI
Any
Do not use
Implementations